@@ -555,7 +555,7 @@ impl Fold for Umd {
             stmts.extend(initialize_to_undefined(exports_ident, initialized));
         }
 
-        for (src, import) in scope.imports.drain(..) {
+        for (src, (src_span, import)) in scope.imports.drain(..) {
             let global_ident = Ident::new(self.config.global_name(&src), DUMMY_SP);
             let import = import.unwrap_or_else(|| {
                 (
@@ -575,7 +575,7 @@ impl Fold for Umd {
             });
             factory_args.push(
                 self.resolver
-                    .make_require_call(self.root_mark, src.clone())
+                    .make_require_call(self.root_mark, src.clone(), src_span)
                     .as_arg(),
             );
             global_factory_args.push(quote_ident!("global").make_member(global_ident).as_arg());
